import click
from auledft.backend.dft_runner import run_dft

@click.command()
@click.argument("input_file")
@click.option("--software", type=click.Choice(["vasp", "qe"]), required=True)
@click.option("--hpc", is_flag=True, help="Run on HPC")
def cli(input_file, software, hpc):
    """Run DFT on a specified input file."""
    result = run_dft(input_file, software, hpc)
    print(result)

if __name__ == "__main__":
    cli()



from setuptools import setup, find_packages

setup(
    name="auledft",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        "ase",
        "numpy",
        "click",
        "streamlit",  # Se usi Streamlit
    ],
    entry_points={
        "console_scripts": [
            "auledft=auledft.cli:cli",
        ],
    },
)
